searchData={"items":[{"type":"module","title":"ScrollexEcto","doc":"ScrollexEcto is a pagination library for Ecto queries.\n\nIt provides both offset-based and cursor-based pagination methods.","ref":"ScrollexEcto.html"},{"type":"macro","title":"ScrollexEcto.__using__/1","doc":"A macro that injects pagination functionality into the using module.","ref":"ScrollexEcto.html#__using__/1"},{"type":"macro","title":"Options - ScrollexEcto.__using__/1","doc":"The `opts` parameter can include:\n  * `:page_size` - The default number of items per page (default: 10)\n  * `:order_field` - The field to use for ordering in cursor-based pagination (default: :inserted_at)\n  * `:id_field` - The ID field to use as a tie-breaker in cursor-based pagination (default: :id)","ref":"ScrollexEcto.html#__using__/1-options"},{"type":"macro","title":"Example - ScrollexEcto.__using__/1","doc":"defmodule MyRepo do\n      use Ecto.Repo, otp_app: :my_app\n      use ScrollexEcto, page_size: 20\n    end","ref":"ScrollexEcto.html#__using__/1-example"},{"type":"function","title":"ScrollexEcto.paginate/4","doc":"Paginates the given queryable using the ScrollexEcto.Paginator.\n\nThis function is called by the injected `paginate/2` function and shouldn't be used directly.","ref":"ScrollexEcto.html#paginate/4"},{"type":"module","title":"ScrollexEcto.Page","doc":"Represents a page of results from a paginated query.\n\nThis struct is returned by the `ScrollexEcto.Paginator.paginate/4` function.","ref":"ScrollexEcto.Page.html"},{"type":"type","title":"ScrollexEcto.Page.t/0","doc":"Type specification for the ScrollexEcto.Page struct.\n\nFields:\n  * `:entries` - List of items on the current page\n  * `:page_number` - Current page number (for offset-based pagination)\n  * `:page_size` - Number of items per page\n  * `:total_pages` - Total number of pages (for offset-based pagination)\n  * `:total_entries` - Total number of items across all pages (for offset-based pagination)\n  * `:next_cursor` - Cursor for the next page (for cursor-based pagination)","ref":"ScrollexEcto.Page.html#t:t/0"},{"type":"module","title":"ScrollexEcto.Paginator","doc":"Provides pagination functionality for Ecto queries.\n\nThis module implements both offset-based and cursor-based pagination methods.","ref":"ScrollexEcto.Paginator.html"},{"type":"function","title":"ScrollexEcto.Paginator.paginate/4","doc":"Paginates the given queryable based on the provided parameters.","ref":"ScrollexEcto.Paginator.html#paginate/4"},{"type":"function","title":"Parameters - ScrollexEcto.Paginator.paginate/4","doc":"* `queryable` - The Ecto queryable to paginate\n  * `params` - A map of pagination parameters\n  * `repo` - The Ecto repo to use for queries\n  * `conf` - Configuration options","ref":"ScrollexEcto.Paginator.html#paginate/4-parameters"},{"type":"function","title":"Returns - ScrollexEcto.Paginator.paginate/4","doc":"A `ScrollexEcto.Page` struct containing the paginated results.","ref":"ScrollexEcto.Paginator.html#paginate/4-returns"},{"type":"extras","title":"ScrollexEcto","doc":"# ScrollexEcto\n\nScrollexEcto is a flexible pagination library for Elixir and Ecto, supporting both offset-based and cursor-based pagination.","ref":"readme.html"},{"type":"extras","title":"Installation - ScrollexEcto","doc":"Add `scrollex_ecto` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:scrollex_ecto, \"~> 0.1.0+minor\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ScrollexEcto","doc":"Add ScrollexEcto to your Repo module:\n```elixir\ndefmodule MyApp.Repo do\n  use Ecto.Repo,\n    otp_app: :my_app,\n    adapter: Ecto.Adapters.Postgres\n\n  use ScrollexEcto,\n    page_size: 10,\n    order_field: :inserted_at,\n    id_field: :id\nend\n```\nThen you can use it in your queries:\n```elixir\n# Offset-based pagination\nMyApp.Repo.paginate(MyApp.Item, %{\"page\" => 2, \"page_size\" => 20})\n\n# Cursor-based pagination\nMyApp.Repo.paginate(MyApp.Item, %{\"page_type\" => \"cursor\", \"cursor\" => \"some_cursor\", \"page_size\" => 20})\n```\n\nFor more detailed usage and configuration options, please refer to the (documentation)[https://hexdocs.pm/scrollex_ecto].","ref":"readme.html#usage"},{"type":"extras","title":"Author - ScrollexEcto","doc":"ScrollexEcto is created and maintained by Yatender Singh Suman.","ref":"readme.html#author"},{"type":"extras","title":"License - ScrollexEcto","doc":"Copyright (c) 2024 Yatender Singh Suman\n\nScrollexEcto is released under the MIT License. See the [LICENSE](https://github.com/yatender-oktalk/scrollex_ecto/blob/main/LICENSE) file for details.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}